# `4711`
[![pypi](https://badge.fury.io/py/4711.svg)](https://pypi.python.org/pypi/4711/)
[![Made with Python](https://img.shields.io/pypi/pyversions/4711)](https://www.python.org/)
[![MIT License](https://img.shields.io/github/license/kalaspuff/4711.svg)](https://github.com/kalaspuff/4711/blob/master/LICENSE)
[![Code coverage](https://codecov.io/gh/kalaspuff/4711/branch/master/graph/badge.svg)](https://codecov.io/gh/kalaspuff/4711/tree/master/4711)

*A collection of CLI tools for working with data structures, parsing values, conversion and formatting. Requires Python 3.6, Python 3.7 or Python 3.8.*


## Installation with `pipx` (preferred) or `pip`
It's recommended to install `4711` using `pipx`, which is a tool that stores CLI's in their own virtual environments without you having to think about it or handle the dependencies.

`pipx` is available at [https://github.com/pipxproject/pipx](https://github.com/pipxproject/pipx).

To install using `pipx` (depending on how you've installed `pipx` previously, may have to use `sudo`):
```
$ pipx install 4711
```

If you prefer to install the CLI normally using `pip`, go ahead and run:
```
$ pip install 4711
```


## Usage and examples

#### Use-case
```
$ 4711 --help

```
